@@ -28,6 +28,7 @@
 #include <KWindowSystem>
 #endif
 
+#include "networkaccessmanagerfactory.h"
 #include "plasmatube-version.h"
 
 #ifdef Q_OS_ANDROID
@@ -86,7 +87,7 @@ int main(int argc, char **argv)
                 auto args = arguments;
                 args.removeFirst();
 
-                if (!arguments.empty()) {
+                if (!args.empty()) {
                     if (const auto videoUrl = LinkParser::parseVideoString(args[0])) {
                         PlasmaTube::instance().openVideo(*videoUrl);
                     }
@@ -100,6 +101,9 @@ int main(int argc, char **argv)
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
+    NetworkAccessManagerFactory namFactory;
+    engine.setNetworkAccessManagerFactory(&namFactory);
+
     QCommandLineParser parser;
     parser.addPositionalArgument(QStringLiteral("video-url"), QStringLiteral("YouTube video URL to play"));
 
